@@ -47,6 +47,17 @@ def test_simple(dir_server):
     assert data == open(os.path.join(dir_server, fn), 'rb').read()
 
 
+def test_fetch_range_with_headers(dir_server):
+    # https://github.com/dask/dask/issues/4479
+    root = 'http://localhost:8999/'
+    fn = files[0]
+    headers = {'Date': 'Wed, 21 Oct 2015 07:28:00 GMT'}
+    f = open_files(root + fn, headers=headers)[0]
+    with f as f:
+        data = f.read(length=1) + f.read(length=-1)
+    assert data == open(os.path.join(dir_server, fn), 'rb').read()
+
+
 @pytest.mark.parametrize('block_size', [None, 99999])
 def test_ops(dir_server, block_size):
     root = 'http://localhost:8999/'
@@ -126,6 +137,7 @@ def test_parquet():
                                    'n_comment']
 
 
+@pytest.mark.xfail(reason="https://github.com/dask/dask/issues/3696")
 @pytest.mark.network
 def test_bag():
     # This test pulls from different hosts
