@@ -19,9 +19,9 @@ except ImportError:
 
 from ...bytes import read_bytes, open_files
 from ...bytes.compression import seekable_files, files as cfiles
-from ...compatibility import PY2, PY3, Mapping
+from ...compatibility import PY2, PY3, Mapping, unicode
 from ...delayed import delayed
-from ...utils import asciitable
+from ...utils import asciitable, parse_bytes
 
 from ..utils import clear_known_categories, PANDAS_VERSION
 
@@ -318,6 +318,8 @@ def read_pandas(reader, urlpath, blocksize=AUTO_BLOCKSIZE, collection=True,
     else:
         path_converter = None
 
+    if isinstance(blocksize, (str, unicode)):
+        blocksize = parse_bytes(blocksize)
     if blocksize and compression not in seekable_files:
         warn("Warning %s compression does not support breaking apart files\n"
              "Please ensure that each individual file can fit in memory and\n"
@@ -424,10 +426,11 @@ urlpath : string or list
     to read from alternative filesystems. To read from multiple files you
     can pass a globstring or a list of paths, with the caveat that they
     must all have the same protocol.
-blocksize : int or None, optional
+blocksize : str, int or None, optional
     Number of bytes by which to cut up larger files. Default value is
     computed based on available physical memory and the number of cores.
     If ``None``, use a single block for each file.
+    Can be a number like 64000000 or a string like "64MB"
 collection : boolean, optional
     Return a dask.dataframe if True or list of dask.delayed objects if False
 sample : int, optional
@@ -491,6 +494,7 @@ def make_reader(reader, reader_name, file_type):
 
 read_csv = make_reader(pd.read_csv, 'read_csv', 'CSV')
 read_table = make_reader(pd.read_table, 'read_table', 'delimited')
+read_fwf = make_reader(pd.read_fwf, 'read_fwf', 'fixed-width')
 
 
 def _write_csv(df, fil, **kwargs):
@@ -499,7 +503,8 @@ def _write_csv(df, fil, **kwargs):
 
 
 def to_csv(df, filename, name_function=None, compression=None, compute=True,
-           get=None, scheduler=None, storage_options=None, **kwargs):
+           scheduler=None, storage_options=None,
+           header_first_partition_only=False, **kwargs):
     """
     Store Dask DataFrame to CSV files
 
@@ -567,6 +572,8 @@ def to_csv(df, filename, name_function=None, compression=None, compute=True,
     header : boolean or list of string, default True
         Write out column names. If a list of string is given it is assumed
         to be aliases for the column names
+    header_first_partition_only : boolean, default False
+        If set, only write the header row in the first output file
     index : boolean, default True
         Write row names (index)
     index_label : string or sequence, or False, default None
@@ -629,11 +636,22 @@ def to_csv(df, filename, name_function=None, compression=None, compute=True,
                        num=df.npartitions, **(storage_options or {}))
 
     to_csv_chunk = delayed(_write_csv, pure=False)
-    values = [to_csv_chunk(d, f, **kwargs)
-              for d, f in zip(df.to_delayed(), files)]
+
+    dfs = df.to_delayed()
+
+    # If we only want headers in the first file, turn headers off after the
+    # first partition
+
+    values = [to_csv_chunk(dfs[0], files[0], **kwargs)]
+
+    if len(dfs) > 1:
+        if header_first_partition_only:
+            kwargs['header'] = False
+        values.extend([to_csv_chunk(d, f, **kwargs)
+                       for d, f in zip(dfs[1:], files[1:])])
 
     if compute:
-        delayed(values).compute(get=get, scheduler=scheduler)
+        delayed(values).compute(scheduler=scheduler)
         return [f.path for f in files]
     else:
         return values
