@@ -14,7 +14,7 @@ from ...compatibility import unicode, PY3
 from ... import array as da
 from ...delayed import delayed
 
-from ..core import DataFrame, Series, new_dd_object
+from ..core import DataFrame, Series, Index, new_dd_object, has_parallel_type
 from ..shuffle import set_partition
 from ..utils import insert_meta_param_description, check_meta, make_meta
 
@@ -165,7 +165,7 @@ def from_pandas(data, npartitions=None, chunksize=None, sort=True, name=None):
     if isinstance(getattr(data, 'index', None), pd.MultiIndex):
         raise NotImplementedError("Dask does not support MultiIndex Dataframes.")
 
-    if not isinstance(data, (pd.Series, pd.DataFrame)):
+    if not has_parallel_type(data):
         raise TypeError("Input must be a pandas DataFrame or Series")
 
     if ((npartitions is None) == (chunksize is None)):
@@ -192,9 +192,8 @@ def from_pandas(data, npartitions=None, chunksize=None, sort=True, name=None):
         locations = list(range(0, nrows, chunksize)) + [len(data)]
         divisions = [None] * len(locations)
 
-    dsk = dict(((name, i), data.iloc[start: stop])
-               for i, (start, stop) in enumerate(zip(locations[:-1],
-                                                     locations[1:])))
+    dsk = {(name, i): data.iloc[start: stop]
+           for i, (start, stop) in enumerate(zip(locations[:-1], locations[1:]))}
     return new_dd_object(dsk, name, data, divisions)
 
 
@@ -342,16 +341,27 @@ def dataframe_from_ctable(x, slc, columns=None, categories=None, lock=lock):
     return result
 
 
-def from_dask_array(x, columns=None):
+def from_dask_array(x, columns=None, index=None):
     """ Create a Dask DataFrame from a Dask Array.
 
     Converts a 2d array into a DataFrame and a 1d array into a Series.
 
     Parameters
     ----------
-    x: da.Array
-    columns: list or string
+    x : da.Array
+    columns : list or string
         list of column names if DataFrame, single string if Series
+    index : dask.dataframe.Index, optional
+        An optional *dask* Index to use for the output Series or DataFrame.
+
+        The default output index depends on whether `x` has any unknown
+        chunks. If there are any unknown chunks, the output has ``None``
+        for all the divisions (one per chunk). If all the chunks are known,
+        a default index with known divsions is created.
+
+        Specifying `index` can be useful if you're conforming a Dask Array
+        to an existing dask Series or DataFrame, and you would like the
+        indices to match.
 
     Examples
     --------
@@ -378,7 +388,22 @@ def from_dask_array(x, columns=None):
         x = x.rechunk({1: x.shape[1]})
 
     name = 'from-dask-array' + tokenize(x, columns)
-    if np.isnan(sum(x.shape)):
+    to_merge = []
+
+    if index is not None:
+        if not isinstance(index, Index):
+            raise ValueError("'index' must be an instance of dask.dataframe.Index")
+        if index.npartitions != x.numblocks[0]:
+            msg = (
+                "'index' must have the same number of blocks as 'x'. "
+                "({} != {})".format(index.npartitions, x.numblocks[0])
+            )
+            raise ValueError(msg)
+        divisions = index.divisions
+        to_merge.append(ensure_dict(index.dask))
+        index = index.__dask_keys__()
+
+    elif np.isnan(sum(x.shape)):
         divisions = [None] * (len(x.chunks[0]) + 1)
         index = [None] * len(x.chunks[0])
     else:
@@ -398,7 +423,8 @@ def from_dask_array(x, columns=None):
         else:
             dsk[name, i] = (pd.DataFrame, chunk, ind, meta.columns)
 
-    return new_dd_object(merge(ensure_dict(x.dask), dsk), name, meta, divisions)
+    to_merge.extend([ensure_dict(x.dask), dsk])
+    return new_dd_object(merge(*to_merge), name, meta, divisions)
 
 
 def _link(token, result):
@@ -473,7 +499,7 @@ def from_delayed(dfs, meta=None, divisions=None, prefix='from-delayed'):
     $META
     divisions : tuple, str, optional
         Partition boundaries along the index.
-        For tuple, see http://dask.pydata.org/en/latest/dataframe-design.html#partitions
+        For tuple, see https://docs.dask.org/en/latest/dataframe-design.html#partitions
         For string 'sorted' will compute the delayed values to find index
         values.  Assumes that the indexes are mutually sorted.
         If None, then won't use index information
