@@ -16,8 +16,9 @@ def test_make_timeseries():
     assert df['A'].head().dtype == float
     assert df['B'].head().dtype == int
     assert df['C'].head().dtype == object
-    assert df.divisions == tuple(pd.DatetimeIndex(start='2000', end='2015',
-                                                  freq='6M'))
+    assert df.index.name == 'timestamp'
+    assert df.head().index.name == df.index.name
+    assert df.divisions == tuple(pd.date_range(start='2000', end='2015',freq='6M'))
 
     tm.assert_frame_equal(df.head(), df.head())
 
