@@ -390,8 +390,8 @@ def _nonempty_index(idx):
         return pd.DatetimeIndex(data, start=start, periods=2, freq=idx.freq,
                                 tz=idx.tz, name=idx.name)
     elif typ is pd.PeriodIndex:
-        return pd.PeriodIndex(start='1970-01-01', periods=2, freq=idx.freq,
-                              name=idx.name)
+        return pd.period_range(start='1970-01-01', periods=2, freq=idx.freq,
+                               name=idx.name)
     elif typ is pd.TimedeltaIndex:
         start = np.timedelta64(1, 'D')
         data = [start, start + 1] if idx.freq is None else None
